@@ -12,16 +12,18 @@
 
 #include <kwidgetsaddons_export.h>
 
+#include <QDate>
 #include <QFrame>
 #include <memory>
 
 class QLineEdit;
 class KDateTable;
 
-/**
- * @class KDatePicker kdatepicker.h KDatePicker
+/*!
+ * \class KDatePicker
+ * \inmodule KWidgetsAddons
  *
- * @short A date selection widget.
+ * \brief A date selection widget.
  *
  * Provides a widget for calendar date input.
  *
@@ -32,34 +34,40 @@ class KDateTable;
  * to select a date directly by entering numbers like 19990101
  * or 990101.
  *
- * \image html kdatepicker.png "KDatePicker Widget"
- *
- * @author Tim Gilman, Mirko Boehm
+ * \image kdatepicker.png "KDatePicker Widget"
  */
 class KWIDGETSADDONS_EXPORT KDatePicker : public QFrame
 {
     Q_OBJECT
+    /*!
+     * \property KDatePicker::date
+     */
     Q_PROPERTY(QDate date READ date WRITE setDate NOTIFY dateChanged USER true)
+
+    /*!
+     * \property KDatePicker::closeButton
+     */
     Q_PROPERTY(bool closeButton READ hasCloseButton WRITE setCloseButton)
+
+    /*!
+     * \property KDatePicker::fontSize
+     */
     Q_PROPERTY(int fontSize READ fontSize WRITE setFontSize)
 
 public:
-    /**
+    /*!
      * The constructor. The current date will be displayed initially.
      */
     explicit KDatePicker(QWidget *parent = nullptr);
 
-    /**
+    /*!
      * The constructor. The given date will be displayed initially.
      */
     explicit KDatePicker(const QDate &dt, QWidget *parent = nullptr);
 
-    /**
-     * The destructor.
-     */
     ~KDatePicker() override;
 
-    /**
+    /*!
      * The size hint for date pickers. The size hint recommends the
      * minimum size of the widget so that all elements may be placed
      * without clipping. This sometimes looks ugly, so when using the
@@ -68,48 +76,63 @@ public:
      */
     QSize sizeHint() const override;
 
-    /**
+    /*!
      * Sets the date.
      *
-     * @returns @p false and does not change anything if the date given is invalid.
+     * Returns \c false and does not change anything if the date given is invalid.
      */
     bool setDate(const QDate &date);
 
-    /**
-     * @returns the selected date.
+    /*!
+     * Returns the selected date.
      */
     const QDate &date() const;
 
-    /**
+    /*!
      * Sets the font size of the widgets elements.
      */
     void setFontSize(int);
 
-    /**
+    /*!
      * Returns the font size of the widget elements.
      */
     int fontSize() const;
 
-    /**
-     * By calling this method with @p enable = true, KDatePicker will show
+    /*!
+     * By calling this method with \a enable = true, KDatePicker will show
      * a little close-button in the upper button-row. Clicking the
      * close-button will cause the KDatePicker's topLevelWidget()'s close()
      * method being called. This is mostly useful for toplevel datepickers
      * without a window manager decoration.
-     * @see hasCloseButton
+     * \sa hasCloseButton
      */
     void setCloseButton(bool enable);
 
-    /**
-     * @returns true if a KDatePicker shows a close-button.
-     * @see setCloseButton
+    /*!
+     * Returns true if a KDatePicker shows a close-button.
+     * \sa setCloseButton
      */
     bool hasCloseButton() const;
 
+    /*!
+     * Sets the range of dates that can be accepted.
+     *
+     * Invalid dates can be used to define open-ended ranges.
+     * If both values are valid, the minimum date must be less than
+     * or equal to the maximum date, otherwise the date range will
+     * not be set.
+     *
+     * \a minDate the minimum date
+     *
+     * \a maxDate the maximum date
+     *
+     * \since 6.12
+     */
+    void setDateRange(const QDate &minDate, const QDate &maxDate = QDate());
+
 protected:
-    /// to catch move keyEvents when QLineEdit has keyFocus
+    // to catch move keyEvents when QLineEdit has keyFocus
     bool eventFilter(QObject *o, QEvent *e) override;
-    /// the resize event
     void resizeEvent(QResizeEvent *) override;
     void changeEvent(QEvent *event) override;
 
@@ -128,16 +151,16 @@ protected Q_SLOTS:
     void weekSelected(int);
 
 Q_SIGNALS:
-    /**
+    /*!
      * This signal is emitted each time the selected date is changed.
      * Usually, this does not mean that the date has been entered,
      * since the date also changes, for example, when another month is
      * selected.
-     * @see dateSelected
+     * \sa dateSelected
      */
     void dateChanged(const QDate &date);
 
-    /**
+    /*!
      * This signal is emitted each time a day has been selected by
      * clicking on the table (hitting a day in the current month). It
      * has the same meaning as dateSelected() in older versions of
@@ -145,7 +168,7 @@ Q_SIGNALS:
      */
     void dateSelected(const QDate &date);
 
-    /**
+    /*!
      * This signal is emitted when enter is pressed and a VALID date
      * has been entered before into the line edit. Connect to both
      * dateEntered() and dateSelected() to receive all events where the
@@ -153,7 +176,7 @@ Q_SIGNALS:
      */
     void dateEntered(const QDate &date);
 
-    /**
+    /*!
      * This signal is emitted when the day has been selected by
      * clicking on it in the table.
      */
